==> qbittorrent_4.1.7.orig.tar.xz: qbittorrent-4.1.7/src/base/algorithm.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2018  Vladimir Golovnev <glassez@yandex.ru>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#pragma once

namespace Dict
{
    // To be used with QMap, QHash and it's variants
    template <typename Dictionary, typename BinaryPredicate>
    void removeIf(Dictionary &&dict, BinaryPredicate p)
    {
        auto it = dict.begin();
        while (it != dict.end())
            it = (p(it.key(), it.value()) ? dict.erase(it) : it + 1);
    }
}

==> qbittorrent_4.2.5.orig.tar.xz: qbittorrent-4.2.5/src/base/algorithm.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2018  Vladimir Golovnev <glassez@yandex.ru>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#pragma once

#include <type_traits>

namespace Algorithm
{
    template <typename ...>
    using void_t = void;  // replace this with std::void_t in C++17

    template <typename T, typename = void>
    struct HasMappedType
        : std::false_type
    {
    };

    template <typename T>
    struct HasMappedType<T, void_t<typename T::mapped_type>>
        : std::true_type
    {
    };

    // To be used with associative array types, such as QMap, QHash and it's variants
    template <typename T, typename BinaryPredicate
        , typename std::enable_if_t<HasMappedType<T>::value, int> = 0>
    void removeIf(T &dict, BinaryPredicate &&p)
    {
        auto it = dict.begin();
        while (it != dict.end())
            it = (p(it.key(), it.value()) ? dict.erase(it) : (it + 1));
    }

    // To be used with set types, such as QSet, std::set
    template <typename T, typename UnaryPredicate
        , typename std::enable_if_t<!HasMappedType<T>::value, int> = 0>
    void removeIf(T &set, UnaryPredicate &&p)
    {
        auto it = set.begin();
        while (it != set.end())
            it = (p(*it) ? set.erase(it) : (it + 1));
    }
}
